laue\_dials.algorithms namespace
================================

.. py:module:: laue_dials.algorithms

Submodules
----------

laue\_dials.algorithms.laue module
----------------------------------

.. automodule:: laue_dials.algorithms.laue
   :members:
   :undoc-members:
   :show-inheritance:

laue\_dials.algorithms.outliers module
--------------------------------------

.. automodule:: laue_dials.algorithms.outliers
   :members:
   :undoc-members:
   :show-inheritance:
